@@ -51,15 +51,24 @@ L<MARC::File::XML>
 package Catmandu::Importer::MARC::XML;
 use Catmandu::Sane;
 use Moo;
+use Catmandu::Importer::MARC::Decoder;
 use MARC::File::XML (BinaryEncoding => 'UTF-8', DefaultEncoding => 'UTF-8', RecordFormat => 'MARC21');
 
-extends 'Catmandu::Importer::MARC::Record';
+with 'Catmandu::Importer';
+
+has id        => (is => 'ro' , default => sub { '001' });
+has decoder   => (
+    is   => 'ro',
+    lazy => 1 , 
+    builder => sub {
+        Catmandu::Importer::MARC::Decoder->new;
+    } );
 
 sub generator {
     my ($self) = @_;
     my $file = MARC::File::XML->in($self->fh);
     sub  {
-      $self->decode_marc($file->next());
+      $self->decoder->decode($file->next(),$self->id);
     }
 }
 
